# iss-lidar
Lidar processing scripts for the NSF NCAR [EOL](https://www.eol.ucar.edu/) [Integrated Sounding System](https://www.eol.ucar.edu/observing_facilities/iss). These scripts are currently used to work with data from a Leosphere WindCube scanning wind lidar.

Currently this library performs two main functions: calculating velocity-azimuth display (VAD) winds from PPI scans, and calculating 30-minute consensus averaged winds from VAD winds.

This code was developed at EOL based on examples from Josh Gebauer, now at the University of Oklahoma. Subsequent development by Matt Paulus, Carol Ruchti, Bill Brown, Jacquie Witte, and Isabel Suhr (all EOL). Python package is maintained by Isabel Suhr.
